@@ -1,18 +1,25 @@
 import logging
+from typing import Dict
+from typing import List
+from typing import Union
 
-from flask import abort, jsonify, make_response, Response, request
-
-from typing import Dict, List, Union
-
-
-from JuMonC.handlers.base import api_version_path, check_version, RESTAPI, generate_cache_id, get_prefer_id_description
-from JuMonC.authentication import scopes
-from JuMonC.authentication.check import check_auth
-from JuMonC.models import pluginInformation
-from JuMonC.tasks import disk
-from JuMonC import settings
+from flask import abort
+from flask import jsonify
+from flask import make_response
+from flask import request
+from flask import Response
 
 import JuMonC.models.cache.helper as cache
+from JuMonC import settings
+from JuMonC.authentication import scopes
+from JuMonC.authentication.check import check_auth
+from JuMonC.handlers.base import api_version_path
+from JuMonC.handlers.base import check_version
+from JuMonC.handlers.base import generate_cache_id
+from JuMonC.handlers.base import get_prefer_id_description
+from JuMonC.handlers.base import RESTAPI
+from JuMonC.models import pluginInformation
+from JuMonC.tasks import disk
 
 
 logger = logging.getLogger(__name__)
@@ -27,21 +34,21 @@ io_path = "/io"
 @check_version
 @check_auth(scopes["see_links"])
 def returnIOLinks(version: int) -> Response:
-    logging.debug("Accessed /v%i/io/", version)
+    logger.debug("Accessed /v%i/io/", version)
     return make_response(jsonify(sorted(links, key=lambda dic: dic['link'])), 200)
 
 @RESTAPI.route(api_version_path + io_path + "/status", methods=["GET"])
 @check_version
 @check_auth(scopes["see_links"])
 def returnIOStatusLinks(version: int) -> Response:
-    logging.debug("Accessed /v%i/io/status", version)
+    logger.debug("Accessed /v%i/io/status", version)
     return make_response(jsonify(sorted(status_links, key=lambda dic: dic['link'])), 200)
 
 @RESTAPI.route(api_version_path + io_path + "/config", methods=["GET"])
 @check_version
 @check_auth(scopes["see_links"])
 def returnIOConfigLinks(version: int) -> Response:
-    logging.debug("Accessed /v%i/io/config", version)
+    logger.debug("Accessed /v%i/io/config", version)
     return make_response(jsonify(sorted(config_links, key=lambda dic: dic['link'])), 200)
 
 def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
@@ -96,7 +103,7 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
         def returnIOStatus(version: int, datatype:str, cache_id:int) -> Response:
             duration = request.args.get('duration', default = -1.0, type = float)
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
-            logging.debug("Accessed /v%i/io/status/%s", version, datatype)
+            logger.debug("Accessed /v%i/io/status/%s", version, datatype)
             
             if duration >0:
                 cache.addParameter(cache_id, "duration", str(duration))
@@ -107,13 +114,13 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
                                                overrideHumanReadableWithValue = humanReadable)
             if len(data) > 0:
                 for data_element in data:
-                    logging.debug(str(data_element))
+                    logger.debug(str(data_element))
                     for result_name, result in data_element.items():
                         cache.addResult(cache_id, result_name, result)
                 cache.commit()
                 return make_response(jsonify(data), 200)
             
-            logging.warning("Accessed /v%i/io/status/%s, but not avaiable", version, datatype)
+            logger.warning("Accessed /v%i/io/status/%s, but not avaiable", version, datatype)
             abort(404)
             return make_response("",404)
         
@@ -151,12 +158,12 @@ def registerConfigLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
         @check_auth(scopes["compute_data"])
         def returnIOConfig(version: int, datatype:str) -> Response:
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
-            logging.debug("Accessed /v%i/io/config/%s", version, datatype)
+            logger.debug("Accessed /v%i/io/config/%s", version, datatype)
             data = disk.plugin.getConfigData(dataType = datatype, overrideHumanReadableWithValue = humanReadable)
             if len(data) > 0:
                 return make_response(jsonify(data), 200)
             
-            logging.warning("Accessed /v%i/io/config/%s, but not avaiable", version, datatype)
+            logger.warning("Accessed /v%i/io/config/%s, but not avaiable", version, datatype)
             abort(404)
             return make_response("",404)
         
