@@ -1,5 +1,9 @@
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Union
+
 import pluggy
-from typing import List, Dict, Union, Any
 
 hookspec = pluggy.HookspecMarker("JuMonC")
 
@@ -92,4 +96,4 @@ def selfcheck_is_working() -> bool:
 
 
 
-#pylint: enable=unused-argument
\ No newline at end of file
+#pylint: enable=unused-argument
