@@ -1,9 +1,9 @@
 """settings package of JuMonC, central place for settings."""
-
-
 import os
-
-from typing import List, Optional, Tuple, Union
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Union
 
 from JuMonC.settings.helpers import parse_boolean
 
@@ -12,11 +12,13 @@ LOG_STDOUT: bool = parse_boolean(os.environ.get("JUMONC_LOG_STDOUT", "false"))
 LOG_PREFIX: str = os.environ.get("JUMONC_LOG_PREFIX", "")
 LOG_FORMAT: str = os.environ.get(
     "JUMONC_LOG_FORMAT",
-    LOG_PREFIX + "[%(asctime)s][PID:%(process)d][%(levelname)s][%(name)s] %(message)s",
+    "[%(asctime)s][PID:%(process)d][%(levelname)s][%(name)s] %(message)s",
 )
-
+LOGGING_MPI_RANKS = [0]
 
 REST_API_PORT: int = -1
+FLASK_DEBUG = False
+FLASK_HOST:str = "0.0.0.0" # nosec B104
 
 
 PENDING_TASKS_SOFT_LIMIT: int = -1
@@ -53,4 +55,8 @@ MPI_IDs_per_plugin:int = 1000
 
 
 SCHEDULED_TASKS_ENABLED = True
-SCHEDULE_TASKS = []
\ No newline at end of file
+SCHEDULE_TASKS:List[str] = []
+
+
+MPI_reduce_idle_CPU_load = True
+MPI_sleep_timer=0.001
