@@ -1,14 +1,16 @@
 import logging
-
 import time
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Union
 
-from typing import Dict, List, Union, Optional
-
-from JuMonC.tasks import Plugin
-from JuMonC.tasks.taskSwitcher import task_switcher
-from JuMonC.tasks.mpi_helper import multi_node_information
-from JuMonC.helpers import convertNumbers, dicthelper
 from JuMonC import settings
+from JuMonC.helpers import convertNumbers
+from JuMonC.helpers import dicthelper
+from JuMonC.tasks import Plugin
+from JuMonC.tasks.mpi_helper import multi_node_information
+from JuMonC.tasks.taskSwitcher import task_switcher
 
 
 logger = logging.getLogger(__name__)
@@ -39,10 +41,10 @@ class _LinuxNetworkPlugin(Plugin.Plugin):
             with open("/proc/net/dev", encoding="utf8") as file:
                 data = file.read()
         except FileNotFoundError:
-            logging.warning("Could not find the file: \"/proc/net/dev\"", exc_info = True)
+            logger.warning("Could not find the file: \"/proc/net/dev\"", exc_info = True)
             return []
         except PermissionError: 
-            logging.warning("Missing permissions for the file: \"/proc/net/dev\"", exc_info = True)
+            logger.warning("Missing permissions for the file: \"/proc/net/dev\"", exc_info = True)
             return []
         lines = data.split("\n")[2:] # first two lines contain table headings
         for line in lines:
@@ -111,7 +113,7 @@ class _LinuxNetworkPlugin(Plugin.Plugin):
             time.sleep(duration)
             newData = self.getData(dataType = dataType, duration = -1.0, interface = interface, overrideHumanReadableWithValue = False)
             oldData = data
-            data = _getDataDiff(newData = newData, oldData = oldData)
+            data = _getDataDiff(newData = newData, oldData = oldData)  # type: ignore
             data = _divideData(data, duration, "/s")
 
         if overrideHumanReadableWithValue or (overrideHumanReadableWithValue is None and settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) :
@@ -121,29 +123,33 @@ class _LinuxNetworkPlugin(Plugin.Plugin):
     
     def getData(
                 self, dataType: str, duration: float, interface: str, overrideHumanReadableWithValue: Optional[bool] = None
-            ) -> List[Dict[str, Union[str, Dict[str, Union[int, float, str]]]]]:
+            ) -> List[Dict[str, Union[str, Dict[str, Union[int, float, str, List[int], List[float], List[str]]]]]]:
         data = self._getData(dataType = dataType,
                              duration = duration,
                              interface = interface,
                              overrideHumanReadableWithValue = overrideHumanReadableWithValue,
-                             id = self.net_mpi_id)
-        if isinstance(data[0], list): 
+                             id = self.net_mpi_id) # type: ignore
+        if isinstance(data, list) and isinstance(data[0], list): 
             return _reorder_multinode(data)
-        return data
+        return data  # type: ignore
 
 
 plugin = _LinuxNetworkPlugin()
 
 
 
-def _reorder_multinode(dataIn):
+def _reorder_multinode(dataIn: List[List[Dict[str, Union[str, Dict[str, Union[int, float, str]]]]]]
+                      ) -> List[Dict[str, Union[str, Dict[str, Union[List[int], List[float], List[str]]]]]]:
     
-    data: List[Dict[str, Union[str, Dict[str, Union[int, float, str]]]]]= []
+    data: List[Dict[str, Union[str, Dict[str, Union[List[int], List[float], List[str]]]]]]= []
     for i in range(len(dataIn[0])):
         interfaceData = dataIn[0][i]
-        divData: Dict[str, Union[str, Dict[str, Union[int, float, str]]]] = {"interface": interfaceData["interface"]}
-        rec: Dict[str, Union[int, float, str]] = {}
-        trans: Dict[str, Union[int, float, str]] = {}
+        if not isinstance(interfaceData, Dict):
+            logger.error("Unexpected interface data type: %s", type(interfaceData))
+            interfaceData = {"interface": "internalError"}
+        divData: Dict[str, Union[str, Dict[str, Union[List[int], List[float], List[str]]]]] = {"interface": interfaceData["interface"]}  # type: ignore
+        rec: Dict[str, Union[List[int], List[float], List[str]]] = {}
+        trans: Dict[str, Union[List[int], List[float], List[str]]] = {}
         
         recData = interfaceData["received"]
         transData = interfaceData["transmitted"]
@@ -154,19 +160,19 @@ def _reorder_multinode(dataIn):
             if isinstance(recData, dict):
                 value = recData[dataType]
                 if isinstance(value, (int,float)):
-                    rec[dataType] = [dataIn[j][i]["received"][dataType] for j in range(len(dataIn))]
+                    rec[dataType] = [dataIn[j][i]["received"][dataType] for j in range(len(dataIn))]  # type: ignore
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
+                    logger.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
             else:
                 logging.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
             if isinstance(transData, dict):
                 value = transData[dataType]
                 if isinstance(value, (int,float)):
-                    trans[dataType] = [dataIn[j][i]["transmitted"][dataType] for j in range(len(dataIn))]
+                    trans[dataType] = [dataIn[j][i]["transmitted"][dataType] for j in range(len(dataIn))]  # type: ignore
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
+                    logger.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
+                logger.warning("Unexpected data type in LinuxNetwork._reorder_multinode")
                 
         divData["received"] = rec
         divData["transmitted"] = trans
@@ -213,12 +219,12 @@ def _reduceDataTypes(
             if isinstance(recData, dict):
                 strippedData["received"] = {dataType: recData[dataType]}
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._reduceDataTypes")
+                logger.warning("Unexpected data type in LinuxNetwork._reduceDataTypes")
             transData = interfaceData["transmitted"]
             if isinstance(transData, dict):
                 strippedData["transmitted"] = {dataType: transData[dataType]}
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._reduceDataTypes")
+                logger.warning("Unexpected data type in LinuxNetwork._reduceDataTypes")
             data.append(strippedData)
     return data
 
@@ -248,9 +254,9 @@ def _getDataDiff(
                 if isinstance(newValue, (int,float)) and isinstance(oldValue, (int,float)):
                     rec[dataType] = newValue - oldValue
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._getDataDiff")
+                    logger.warning("Unexpected data type in LinuxNetwork._getDataDiff")
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._getDataDiff")
+                logger.warning("Unexpected data type in LinuxNetwork._getDataDiff")
             
             old = interfaceDataOld["transmitted"]
             new = interfaceDataNew["transmitted"]
@@ -260,9 +266,9 @@ def _getDataDiff(
                 if isinstance(newValue, (int,float)) and isinstance(oldValue, (int,float)):
                     trans[dataType] = newValue - oldValue
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._getDataDiff")
+                    logger.warning("Unexpected data type in LinuxNetwork._getDataDiff")
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._getDataDiff")
+                logger.warning("Unexpected data type in LinuxNetwork._getDataDiff")
                 
         difData["received"] = rec
         difData["transmitted"] = trans
@@ -293,7 +299,7 @@ def _divideData(
                 if isinstance(dataValue, (int,float)):
                     rec[dataType + typeNamePostfix] = dataValue / divisor
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._divideData")
+                    logger.warning("Unexpected data type in LinuxNetwork._divideData")
             else:
                 logging.warning("Unexpected data type in LinuxNetwork._divideData")
             if isinstance(transData, dict):
@@ -301,9 +307,9 @@ def _divideData(
                 if isinstance(dataValue, (int,float)):
                     trans[dataType + typeNamePostfix] = dataValue / divisor
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._divideData")
+                    logger.warning("Unexpected data type in LinuxNetwork._divideData")
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._divideData")
+                logger.warning("Unexpected data type in LinuxNetwork._divideData")
                 
         divData["received"] = rec
         divData["transmitted"] = trans
@@ -332,7 +338,7 @@ def _makeDataHumanReadable(
                     (value, unitPrefix) = convertNumbers.convertBinaryPrefix(dataValue)
                     rec[unitPrefix + dataType] = value
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
+                    logger.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
             else:
                 logging.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
             if isinstance(transData, dict):
@@ -341,11 +347,11 @@ def _makeDataHumanReadable(
                     (value, unitPrefix) = convertNumbers.convertBinaryPrefix(dataValue)
                     trans[unitPrefix + dataType] = value
                 else:
-                    logging.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
+                    logger.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
             else:
-                logging.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
+                logger.warning("Unexpected data type in LinuxNetwork._makeDataHumanReadable")
                 
         divData["received"] = rec
         divData["transmitted"] = trans
         data.append(divData)
-    return data
\ No newline at end of file
+    return data
