@@ -1,16 +1,13 @@
 import logging
-
-from threading import Lock
+import sys
 from enum import Enum
-
-from typing import List, Any
+from threading import Lock
+from time import sleep
 
 import mpi4py
 from mpi4py import MPI
 
-import sys
-
-
+from JuMonC import settings
 from JuMonC.tasks.taskSwitcher import task_switcher
 
 
@@ -38,22 +35,32 @@ class MPIGatherFunctionality(Enum):
     SUM = 4
     ONENODE = 5
     ALL = 6
-    
+
+
+def MPI_barrier(do_barrier:bool = settings.MPI_reduce_idle_CPU_load, wait_timer:float = settings.MPI_sleep_timer) -> None: 
+    if do_barrier:
+        req = comm.Ibarrier()
+        while req.Test() is False:
+            sleep(wait_timer)
 
 
 def keepRunning() -> bool:
     return __keep_running
 
-    
-# stop all MPI handlers
-def MPI_fin(data:List[Any]) -> None:
+def stop() -> None:
     global __keep_running
-    logging.debug("MPI stop data: %s", str(data))
-    
     __keep_running = False
     
+
+    
+# stop all MPI handlers
+def MPI_fin() -> None:
+    logger.debug("MPI stop")
+    stop()
     MPI.Finalize()
+        
     sys.exit(0)
 
 
-stop_handlers_id = task_switcher.addFunction(MPI_fin)
\ No newline at end of file
+stop_handlers_id = task_switcher.addFunction(MPI_fin)
+gatherid:int = -1
